==> haskell-annotated-wl-pprint-0.7.0-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-annotated-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 annotated-wl-pprint
version:              0.7.0
visibility:           public
id:                   annotated-wl-pprint-0.7.0-70TwcJulbP410FZMDCXWmO
key:                  annotated-wl-pprint-0.7.0-70TwcJulbP410FZMDCXWmO
license:              BSD-3-Clause
maintainer:           david@davidchristiansen.dk
author:               Daan Leijen, David Raymond Christiansen
homepage:             https://github.com/david-christiansen/annotated-wl-pprint
synopsis:             The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.

category:             Text
abi:                  28afcb0f7d946501dd075f09a33016d3
exposed:              True
exposed-modules:      Text.PrettyPrint.Annotated.Leijen
import-dirs:          /usr/lib/ghc-9.0.1/site-local/annotated-wl-pprint-0.7.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/annotated-wl-pprint-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/annotated-wl-pprint-0.7.0
hs-libraries:         HSannotated-wl-pprint-0.7.0-70TwcJulbP410FZMDCXWmO
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-annotated-wl-pprint-0.7.0-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-annotated-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 annotated-wl-pprint
version:              0.7.0
visibility:           public
id:                   annotated-wl-pprint-0.7.0-6vyiTB7Qv98BkD7hsY3Ewg
key:                  annotated-wl-pprint-0.7.0-6vyiTB7Qv98BkD7hsY3Ewg
license:              BSD-3-Clause
maintainer:           david@davidchristiansen.dk
author:               Daan Leijen, David Raymond Christiansen
homepage:             https://github.com/david-christiansen/annotated-wl-pprint
synopsis:             The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.

category:             Text
abi:                  d4ba8f7153947bc6576772f47174aae6
exposed:              True
exposed-modules:      Text.PrettyPrint.Annotated.Leijen
import-dirs:          /usr/lib/ghc-9.0.2/site-local/annotated-wl-pprint-0.7.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/annotated-wl-pprint-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/annotated-wl-pprint-0.7.0
hs-libraries:         HSannotated-wl-pprint-0.7.0-6vyiTB7Qv98BkD7hsY3Ewg
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
